/****************************************************************************
Date: 3/9/2002
File: icomhf.hpp	

Description:
	ICOM radio driver for HF radios and single band VHF/UHF radios
	Based on ICOM satellite radio driver with SUB/MAIN commands removed
History: 
	1/15/2002 Initial Version
	2/26/2002 Why doesn't R-8500 work?
	3/9/2002 R-8500 fixed + FM step changed to 100Hz
*****************************************************************************/
#ifndef ICOMHF_HPP
#define ICOMHF_HPP

#include "loctypes.h"	// local types
#include "radio.hpp"	// RADIO base class
#include "icommsg.hpp"	// ICOM serial port message handler


//***** Frequency Step Sizes ***********************************************
const LONG ICOMHF_STEPSIZE	= 10;	// 10 Hz frequency tuning step size
const LONG ICOMHF_FMSTEPSIZE	= 100;	// 100 Hz frequency step in FM mode

class ICOMHF : public RADIO {
private:
	ICOMMSG	Msg;		// ICOM Message handler

	BOOL		eReady;		// ready for next command

	// Rx Params
	LONG		lRxVFOSteps;	// receiver VFO steps
	MODULATION	eRxMode;	// current rx modulation type
	BOOL		eUserHasTunedRx;// TRUE if user changed VFO

	// Tx Params
	LONG		lTxVFOSteps;	// last VFO steps sent to radio
	MODULATION	eTxMode;	// current Tx modulation type
	

	//******************************************************
	// Utilities
	//******************************************************

	// Convert DOUBLE Frequency to LONG
	LONG	FreqtoLong(DOUBLE dFrequency) {

		//************************************************
		// WARNING: this code has a workaround for MS C7 bug
		// converting double to long. Do NOT change!
		//************************************************
		volatile ULONG ulFrequency = (ULONG) dFrequency;
		LONG lFrequency = (LONG) ulFrequency;
		return lFrequency;
	}

	// Get frequency step size for this mode
	LONG	GetStepSize(MODULATION eMode) {
		return (eMode == MODULATION_FM) ?
			ICOMHF_FMSTEPSIZE : ICOMHF_STEPSIZE;
	}

	// Convert Frequency and step size to number of Steps
	LONG	GetSteps(LONG lFrequency, MODULATION eMode) {
		LONG lStepSize = GetStepSize(eMode);
		return ( lFrequency + (lStepSize/2) ) / lStepSize;
	}


	// No copy constructor or assignment allowed
	// Force compile error if attempted
	ICOMHF(const ICOMHF&);
	ICOMHF& operator=(const ICOMHF&);

public:
	// General Functions
	ICOMHF(const RADIOPARAMS& Params);
	BOOL	IsReady() { return eReady; }
	VOID	Update();
	~ICOMHF();

	// Tx Functions
	VOID	SetTxFreq(DOUBLE dFrequency);
	VOID	SetTxMode(MODULATION eMode);

	// Rx Functions
	BOOL	HasUserTunedRx() { return eUserHasTunedRx; }
	VOID	RefreshRxParams();
	DOUBLE	GetRxFreq();
	MODULATION GetRxMode() { return eRxMode; }
	VOID	SetRxFreq(DOUBLE dFrequency);
	VOID	SetRxMode(MODULATION eMode);

};
#endif // end icomhf.hpp
