/****************************************************************************
Date: 10/23/95
File: ppdrv.cpp
Description:
	Parallel Port Driver

*****************************************************************************/
#include "ppdrv.hpp"

// Constructor
PPORTDRIVER::PPORTDRIVER() : Address(0) { }

BOOL PPORTDRIVER::Open(USHORT unPortNumber, IOADDRESS IOAddress) {

	BitImage = 0;

	Address = IOAddress ? IOAddress : GetAddress(unPortNumber);
	if (Address == 0) {
		return BOOL_FALSE;
	}

	outp(Address+2, 0x04);	// reset port

	// Need to give port a little time
	INTERVALTIMER	Timer;
	Timer.Start(1);		// 1 second
	while( !Timer.IsExpired() ) { }

	outp(Address+2, 0x00);	// enable port, leave SELECT disabled
	outp(Address, 0);	// clear all data bits
	return BOOL_TRUE;
}

PPORTBITS PPORTDRIVER::ReadStatus() {
	
	return (PPORTBITS) inp(Address+1);
}

VOID PPORTDRIVER::Write(PPORTBITS Bits) {
	BitImage = Bits;
	outp(Address, Bits);
	return;
}

VOID PPORTDRIVER::SetBits(PPORTBITS Bits) {
	Write( BitImage | Bits );
	return;
}

VOID PPORTDRIVER::ClearBits(PPORTBITS Bits) {
	Write ( BitImage & ~Bits);
	return;
}

BOOL PPORTDRIVER::CheckStatus(PPORTBITS Bits) {
	return (ReadStatus() & Bits) ? BOOL_TRUE : BOOL_FALSE;
}

VOID PPORTDRIVER::Close() {
	if (Address != 0) {
		outp(Address, 0);	// clear all bits
		Address = 0;
	}
	return;
};

IOADDRESS PPORTDRIVER::GetAddress(USHORT unPortNumber) {
	unPortNumber--;
	if ( unPortNumber >= PPORTDRIVER_MAXPORT ) {
		return 0;
	}
	return *( (IOADDRESS FAR*) MK_FP(PPORTBIOSSEGMENT,
					PPORTBIOSOFFSET + unPortNumber*2) );
}

// end ppdrv.cpp
